/*
 * Author: Neil Kolban
 * Date: 6/27/2002
 * 
 * SimpleGet
 * ---------
 * This application demonstrates getting messages to an MQSeries queue from
 * a C# application in the .NET framework.
 * 
 * The application reads messages from a named queue and writes each message
 * to the console.  It is assumed that the retrieved message contains text.
 * 
 * If no message is available, the application waits for 15 seconds for more
 * messages to arrive before exiting.
 * 
 * The name of the queue and queue manager are supplied as parameters on the
 * command line.
 * 
 * Usage: SimpleGet QName [QmgrName]
 * 
 */
using System;
using MQ;

namespace MQSamples
{
	/// <summary>
	/// Get messages from a queue and display on console.
	/// </summary>
	class SimpleGet
	{
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			if (args.Length == 0)
			{
				Console.WriteLine("Usage: SimpleGett QName [QMgrName]");
				return;
			}
			string qName = args[0];
			string qMgrName = "";
			if (args.Length > 1)
			{
				qMgrName = args[1];
			}

			try
			{
				Console.WriteLine("Sample SimpleGet started");
				MQQueueManager qMgr = new MQQueueManager(qMgrName);
				MQQueue queue = qMgr.AccessQueue(qName,
					MQC.MQOO_INPUT_AS_Q_DEF | MQC.MQOO_FAIL_IF_QUIESCING);
				MQGetMessageOptions gmo = new MQGetMessageOptions();
				gmo.Options = MQC.MQGMO_WAIT;
				gmo.WaitInterval = 15 * 1000;
				gmo.MatchOptions = MQC.MQMO_NONE;
				MQMessage message = new MQMessage();
				while (true)
				{
					try
					{
						queue.Get(message, gmo);
					}
					catch(MQException e)
					{
						if (e.Reason == MQException.MQRC_NO_MSG_AVAILABLE)
						{
							break;
						}
						throw e;
					}
					string line = message.ReadString(message.MessageLength);
					Console.WriteLine("Message <{0}>", line);
				}
				queue.Close();
				qMgr.Disconnect();
			}
			catch(MQException e)
			{
				Console.WriteLine("Error: {0}", e.ToString());
			}
		}
	}
}
